@@ -6,7 +6,7 @@ mainwindow::mainwindow(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::mainwindow)
 {
-    
+    QLocale::setDefault(QLocale(QLocale::English, QLocale::UnitedStates));
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     this->setWindowFlags(Qt::Window);
     
@@ -34,7 +34,7 @@ mainwindow::mainwindow(QWidget *parent) :
     orientationChanged();
     readvalues();
     abouttext = tr("Author: d-iivil<br />Licence: GPL");
-    abouttitle = "CSSU Transitions Tuner " + tr("version") + " 0.1.5";
+    abouttitle = "CSSU Transitions Tuner " + tr("version") + " 0.1.6";
 }
 
 mainwindow::~mainwindow()
@@ -107,7 +107,7 @@ void mainwindow::readvalues()
 
         if (settings.contains("parallax")) {
         QString parallax = settings.value("parallax").toString();
-        double parallaxdouble = parallax.replace('.', ',').toDouble();
+        double parallaxdouble = parallax.toDouble();
         ui->parallax->setValue(parallaxdouble);
         }
 
@@ -124,7 +124,7 @@ void mainwindow::readvalues()
 
      if (settings.contains("deceleration_rate")) {
      QString deceleration_rate = settings.value("deceleration_rate").toString();
-     double deceleration_ratesouble = deceleration_rate.replace('.', ',').toDouble();
+     double deceleration_ratesouble = deceleration_rate.toDouble();
      ui->scrollrate->setValue(deceleration_ratesouble);
      }
 
