@@ -43,6 +43,10 @@
         <source>App menu blur</source>
         <translation>Menü Unschärfe</translation>
     </message>
+    <message>
+        <source>App menu scroll speed</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Parallax</source>
         <translation>Parallax</translation>
